==> kmymoney-5.0.6-1.src.tar.gz: kmymoney-5.0.6/kmymoney/plugins/checkprinting/checkprinting.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "onet.cristian@gmail.com",
                "Name": "Cristian Oneț",
                "Name[ca@valencia]": "Cristian Oneț",
                "Name[ca]": "Cristian Oneț",
                "Name[cs]": "Cristian Oneț",
                "Name[de]": "Cristian Oneț",
                "Name[en_GB]": "Cristian Oneț",
                "Name[es]": "Cristian Oneț",
                "Name[fr]": "Cristian Oneț",
                "Name[gl]": "Cristian Oneț",
                "Name[it]": "Cristian Oneț",
                "Name[nl]": "Cristian Oneț",
                "Name[pl]": "Cristian Oneț",
                "Name[pt]": "Cristian Oneț",
                "Name[pt_BR]": "Cristian Oneț",
                "Name[ru]": "Cristian Oneț",
                "Name[sk]": "Cristian Oneț",
                "Name[sv]": "Cristian Oneț",
                "Name[uk]": "Cristian Oneț",
                "Name[x-test]": "xxCristian Onețxx"
            }
        ],
        "Description": "Provides the capability to print checks",
        "Description[ca@valencia]": "Proporciona la capacitat d'imprimir xecs",
        "Description[ca]": "Proporciona la capacitat d'imprimir xecs",
        "Description[de]": "Stellt die Möglichkeit bereit, Schecks zu drucken",
        "Description[en_GB]": "Provides the capability to print cheques",
        "Description[es]": "Proporciona la capacidad de imprimir cheques",
        "Description[fr]": "Fournit la possibilité d'imprimer des chèques",
        "Description[gl]": "Permite imprimir cheques",
        "Description[it]": "Fornisce la funzionalità di stampa degli assegni",
        "Description[ko]": "수표 인쇄 기능 제공",
        "Description[nl]": "Levert de mogelijkheid checks af te drukken",
        "Description[pl]": "Dostarcza możliwość drukowania czeków",
        "Description[pt]": "Oferece a possibilidade de imprimir cheques",
        "Description[pt_BR]": "Fornece a capacidade de imprimir cheques",
        "Description[sk]": "Poskytuje možnosť tlačiť účty",
        "Description[sv]": "Tillhandahåller möjlighet att skriva ut checkar",
        "Description[uk]": "Можливість друку чеків",
        "Description[x-test]": "xxProvides the capability to print checksxx",
        "EnabledByDefault": true,
        "Icon": "document-print",
        "Id": "checkprinting",
        "License": "GPL",
        "Name": "Check printing",
        "Name[ca@valencia]": "Impressió de xecs",
        "Name[ca]": "Impressió de xecs",
        "Name[de]": "Scheckdruck",
        "Name[en_GB]": "Cheque printing",
        "Name[es]": "Comprobar la impresión",
        "Name[fr]": "Impression de chèques",
        "Name[gl]": "Impresión de cheques",
        "Name[it]": "Stampa degli assegni",
        "Name[nl]": "Printen van een cheque",
        "Name[pl]": "Drukowanie czeków",
        "Name[pt]": "Impressão de cheques",
        "Name[pt_BR]": "Impressão de cheques",
        "Name[sv]": "Checkutskrift",
        "Name[uk]": "Друк чеків",
        "Name[x-test]": "xxCheck printingxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney-5.2.0-5.src.tar.gz: kmymoney-5.2.0/kmymoney/plugins/checkprinting/checkprinting.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "onet.cristian@gmail.com",
                "Name": "Cristian Oneț",
                "Name[ca@valencia]": "Cristian Oneț",
                "Name[ca]": "Cristian Oneț",
                "Name[cs]": "Cristian Oneț",
                "Name[de]": "Cristian Oneț",
                "Name[en_GB]": "Cristian Oneț",
                "Name[eo]": "Cristian Oneț",
                "Name[es]": "Cristian Oneț",
                "Name[et]": "Cristian Oneț",
                "Name[eu]": "Cristian Oneț",
                "Name[fi]": "Cristian Oneț",
                "Name[fr]": "Cristian Oneț",
                "Name[gl]": "Cristian Oneț",
                "Name[ia]": "Cristian Oneț",
                "Name[it]": "Cristian Oneț",
                "Name[ka]": "Cristian Oneț",
                "Name[ko]": "Cristian Oneț",
                "Name[nb]": "Cristian Oneț",
                "Name[nl]": "Cristian Oneț",
                "Name[pl]": "Cristian Oneț",
                "Name[pt]": "Cristian Oneț",
                "Name[pt_BR]": "Cristian Oneț",
                "Name[ru]": "Cristian Oneț",
                "Name[sk]": "Cristian Oneț",
                "Name[sl]": "Cristian Oneț",
                "Name[sv]": "Cristian Oneț",
                "Name[uk]": "Cristian Oneț",
                "Name[x-test]": "xxCristian Onețxx",
                "Name[zh_CN]": "Cristian Oneț",
                "Name[zh_TW]": "Cristian Oneț"
            }
        ],
        "Description": "Provides the capability to print checks",
        "Description[ca@valencia]": "Proporciona la capacitat d'imprimir xecs",
        "Description[ca]": "Proporciona la capacitat d'imprimir xecs",
        "Description[de]": "Stellt die Möglichkeit bereit, Schecks zu drucken",
        "Description[en_GB]": "Provides the capability to print cheques",
        "Description[eo]": "Provizas la kapablon presi ĉekojn",
        "Description[es]": "Proporciona la capacidad de imprimir cheques",
        "Description[et]": "Tšekkide trükkimise võimalus",
        "Description[eu]": "Txekeak inprimatzeko gaitasuna hornitzen du",
        "Description[fi]": "Tarjoaa kyvyn tulostaa shekkejä",
        "Description[fr]": "Fournit la possibilité d'imprimer des chèques",
        "Description[gl]": "Permite imprimir cheques",
        "Description[ia]": "Forni le capacitate de imprimer cheques",
        "Description[it]": "Fornisce la funzionalità di stampa degli assegni",
        "Description[ka]": "გაძლევთ ჩეკების დაბეჭდვის საშუალებას",
        "Description[ko]": "수표 발행 기능 제공",
        "Description[nb]": "Tilbyr muligheten til å skrive ut sjekker",
        "Description[nl]": "Levert de mogelijkheid checks af te drukken",
        "Description[pl]": "Dostarcza możliwość drukowania czeków",
        "Description[pt]": "Oferece a possibilidade de imprimir cheques",
        "Description[pt_BR]": "Fornece a capacidade de imprimir cheques",
        "Description[ru]": "Представляет возможность печати чеков",
        "Description[sk]": "Poskytuje možnosť tlačiť účty",
        "Description[sl]": "Omogoča tiskanje čekov",
        "Description[sv]": "Tillhandahåller möjlighet att skriva ut checkar",
        "Description[uk]": "Можливість друку чеків",
        "Description[x-test]": "xxProvides the capability to print checksxx",
        "Description[zh_CN]": "提供支票打印功能",
        "Description[zh_TW]": "提供列印支票的功能",
        "EnabledByDefault": true,
        "Icon": "document-print",
        "Id": "checkprinting",
        "License": "GPL",
        "Name": "Check printing",
        "Name[ca@valencia]": "Impressió de xecs",
        "Name[ca]": "Impressió de xecs",
        "Name[de]": "Scheckdruck",
        "Name[en_GB]": "Cheque printing",
        "Name[eo]": "Kontroli presadon",
        "Name[es]": "Comprobar la impresión",
        "Name[et]": "Tšeki trükkimine",
        "Name[eu]": "Txeke inprimatzea",
        "Name[fi]": "Sekkien tulostus",
        "Name[fr]": "Impression de chèques",
        "Name[gl]": "Impresión de cheques",
        "Name[ia]": "Imprimente cheque",
        "Name[it]": "Stampa degli assegni",
        "Name[ka]": "შეამოწმეთ ბეჭდვა",
        "Name[ko]": "수표 발행",
        "Name[nb]": "Sjekkutskrift",
        "Name[nl]": "Printen van een cheque",
        "Name[pl]": "Drukowanie czeków",
        "Name[pt]": "Impressão de cheques",
        "Name[pt_BR]": "Impressão de cheques",
        "Name[ru]": "Печать чеков",
        "Name[sk]": "Skontrolovať tlač",
        "Name[sl]": "Tiskanje čekov",
        "Name[sv]": "Checkutskrift",
        "Name[tr]": "Çek yazdırma",
        "Name[uk]": "Друк чеків",
        "Name[x-test]": "xxCheck printingxx",
        "Name[zh_CN]": "支票打印",
        "Name[zh_TW]": "支票列印",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    },
    "X-KDE-ConfigModule": "kmymoney_plugins/kcms/kcm_checkprinting"
}
